/*
 * --------------------------------------------------------------------------------
 * <copyright company="Aspose" file="metafile_rendering_options_data.dart">
 *   Copyright (c) 2022 Aspose.Words for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------
 */

library aspose_words_cloud;

import '../../aspose_words_cloud.dart';

/// Container class for options of metafile rendering.
class MetafileRenderingOptionsData implements ModelBase {
  /// Gets or sets the option that controls how EMF+ Dual metafiles should be rendered.
  MetafileRenderingOptionsData_EmfPlusDualRenderingModeEnum
      _emfPlusDualRenderingMode;

  MetafileRenderingOptionsData_EmfPlusDualRenderingModeEnum
      get emfPlusDualRenderingMode => _emfPlusDualRenderingMode;
  set emfPlusDualRenderingMode(
          MetafileRenderingOptionsData_EmfPlusDualRenderingModeEnum val) =>
      _emfPlusDualRenderingMode = val;

  /// Gets or sets a value indicating whether the raster operations should be emulated.
  bool _emulateRasterOperations;

  bool get emulateRasterOperations => _emulateRasterOperations;
  set emulateRasterOperations(bool val) => _emulateRasterOperations = val;

  /// Gets or sets the option that controls how metafile images should be rendered.
  MetafileRenderingOptionsData_RenderingModeEnum _renderingMode;

  MetafileRenderingOptionsData_RenderingModeEnum get renderingMode =>
      _renderingMode;
  set renderingMode(MetafileRenderingOptionsData_RenderingModeEnum val) =>
      _renderingMode = val;

  /// Gets or sets a value indicating whether to scale fonts in WMF metafile according to metafile size on the page.
  /// The default value is true.
  bool _scaleWmfFontsToMetafileSize;

  bool get scaleWmfFontsToMetafileSize => _scaleWmfFontsToMetafileSize;
  set scaleWmfFontsToMetafileSize(bool val) =>
      _scaleWmfFontsToMetafileSize = val;

  /// Gets or sets the flag, that controls how WMF metafiles with embedded EMF metafiles should be rendered.
  bool _useEmfEmbeddedToWmf;

  bool get useEmfEmbeddedToWmf => _useEmfEmbeddedToWmf;
  set useEmfEmbeddedToWmf(bool val) => _useEmfEmbeddedToWmf = val;

  @override
  void deserialize(Map<String, dynamic> json) {
    if (json == null) {
      throw ApiException(400,
          'Failed to deserialize MetafileRenderingOptionsData data model.');
    }

    if (json.containsKey('EmfPlusDualRenderingMode')) {
      switch (json['EmfPlusDualRenderingMode'] as String) {
        case 'EmfPlusWithFallback':
          emfPlusDualRenderingMode =
              MetafileRenderingOptionsData_EmfPlusDualRenderingModeEnum
                  .emfPlusWithFallback;
          break;
        case 'EmfPlus':
          emfPlusDualRenderingMode =
              MetafileRenderingOptionsData_EmfPlusDualRenderingModeEnum.emfPlus;
          break;
        case 'Emf':
          emfPlusDualRenderingMode =
              MetafileRenderingOptionsData_EmfPlusDualRenderingModeEnum.emf;
          break;
        default:
          emfPlusDualRenderingMode = null;
          break;
      }
    } else {
      emfPlusDualRenderingMode = null;
    }

    if (json.containsKey('EmulateRasterOperations')) {
      emulateRasterOperations = json['EmulateRasterOperations'] as bool;
    } else {
      emulateRasterOperations = null;
    }

    if (json.containsKey('RenderingMode')) {
      switch (json['RenderingMode'] as String) {
        case 'VectorWithFallback':
          renderingMode =
              MetafileRenderingOptionsData_RenderingModeEnum.vectorWithFallback;
          break;
        case 'Vector':
          renderingMode = MetafileRenderingOptionsData_RenderingModeEnum.vector;
          break;
        case 'Bitmap':
          renderingMode = MetafileRenderingOptionsData_RenderingModeEnum.bitmap;
          break;
        default:
          renderingMode = null;
          break;
      }
    } else {
      renderingMode = null;
    }

    if (json.containsKey('ScaleWmfFontsToMetafileSize')) {
      scaleWmfFontsToMetafileSize = json['ScaleWmfFontsToMetafileSize'] as bool;
    } else {
      scaleWmfFontsToMetafileSize = null;
    }

    if (json.containsKey('UseEmfEmbeddedToWmf')) {
      useEmfEmbeddedToWmf = json['UseEmfEmbeddedToWmf'] as bool;
    } else {
      useEmfEmbeddedToWmf = null;
    }
  }

  @override
  Map<String, dynamic> serialize() {
    var _result = <String, dynamic>{};
    if (emfPlusDualRenderingMode != null) {
      switch (emfPlusDualRenderingMode) {
        case MetafileRenderingOptionsData_EmfPlusDualRenderingModeEnum
            .emfPlusWithFallback:
          _result['EmfPlusDualRenderingMode'] = 'EmfPlusWithFallback';
          break;
        case MetafileRenderingOptionsData_EmfPlusDualRenderingModeEnum.emfPlus:
          _result['EmfPlusDualRenderingMode'] = 'EmfPlus';
          break;
        case MetafileRenderingOptionsData_EmfPlusDualRenderingModeEnum.emf:
          _result['EmfPlusDualRenderingMode'] = 'Emf';
          break;
        default:
          break;
      }
    }

    if (emulateRasterOperations != null) {
      _result['EmulateRasterOperations'] = emulateRasterOperations;
    }

    if (renderingMode != null) {
      switch (renderingMode) {
        case MetafileRenderingOptionsData_RenderingModeEnum.vectorWithFallback:
          _result['RenderingMode'] = 'VectorWithFallback';
          break;
        case MetafileRenderingOptionsData_RenderingModeEnum.vector:
          _result['RenderingMode'] = 'Vector';
          break;
        case MetafileRenderingOptionsData_RenderingModeEnum.bitmap:
          _result['RenderingMode'] = 'Bitmap';
          break;
        default:
          break;
      }
    }

    if (scaleWmfFontsToMetafileSize != null) {
      _result['ScaleWmfFontsToMetafileSize'] = scaleWmfFontsToMetafileSize;
    }

    if (useEmfEmbeddedToWmf != null) {
      _result['UseEmfEmbeddedToWmf'] = useEmfEmbeddedToWmf;
    }
    return _result;
  }
}

/// Gets or sets the option that controls how EMF+ Dual metafiles should be rendered.
enum MetafileRenderingOptionsData_EmfPlusDualRenderingModeEnum {
  emfPlusWithFallback,
  emfPlus,
  emf
}

/// Gets or sets the option that controls how metafile images should be rendered.
enum MetafileRenderingOptionsData_RenderingModeEnum {
  vectorWithFallback,
  vector,
  bitmap
}
